/* Sistemas Integrados TECNISA
   Servios

Nome: LIMPA_CONTA_FINANC

Descrio:  Apaga os registros do Contas a pagar e contas a receber

Criao:
14/12/2005 - Andr Rodrigo
*/

CREATE OR REPLACE PROCEDURE LIMPA_CONTA_FINANC
  (P_CDFILIAL    NOTAFISCAL.CDFILIAL%TYPE,
   P_NRLANCTONF  NOTAFISCAL.NRLANCTONF%TYPE,
   P_DTLIMITE    DATE,
   P_EXCLUSAOOK  OUT VARCHAR2) IS

   V_CTCNTPAG   NUMBER;
   V_CTCNTREC   NUMBER;
   V_CTBOLFORA  NUMBER;
   V_CTBOLF     NUMBER;
   V_CTERRO     NUMBER;
   V_CTBAIXA    NUMBER;
   V_CTBOL      NUMBER;
BEGIN
   P_EXCLUSAOOK := 'S';

   /*************************************************************************/
   /*  VERIFICA SE AS CONTAS A PAGAR, BOLETOS E BAIXAS PODEM SER EXCLUDOS  */

   SELECT COUNT(CP.CDFILIAL) INTO V_CTCNTPAG
   FROM  CONTAPAGAR CP
   WHERE CP.CDFILIAL     = P_CDFILIAL
     AND CP.NRLANCTONF   = P_NRLANCTONF;

   IF V_CTCNTPAG > 0 THEN
      /* VERIFICA SE EXISTE BOLETO ACIMA DA DATA LIMITE */
      SELECT COUNT(*) INTO V_CTBOLFORA
      FROM BOLETPAGAR BP, CONTAPAGAR CP
      WHERE CP.CDFILIAL    = P_CDFILIAL
        AND CP.NRLANCTONF  = P_NRLANCTONF
        AND BP.CDFILIAL    = CP.CDFILIBPAG
        AND BP.NRLANBOLPAG = CP.NRLANBOLPAG
        AND BP.DTVENBOLPAG > P_DTLIMITE;

      /* VERIFICA SE EXISTE BAIXA ACIMA DA DATA LIMITE OU OUTROS BOLETOS ACIMA DA DATA LIGADOS A BAIXA*/
      V_CTERRO := 0;
      FOR C_BAIP IN
        (SELECT DISTINCT BA.CDFILIAL, BA.NRBAIXAPAG, BA.DTBAIXAPAG
         FROM BAIXAPAGA BA, BOLETPAGAR BP, CONTAPAGAR CP
         WHERE CP.CDFILIAL    = P_CDFILIAL
           AND CP.NRLANCTONF  = P_NRLANCTONF
           AND BP.CDFILIAL    = CP.CDFILIBPAG
           AND BP.NRLANBOLPAG = CP.NRLANBOLPAG
           AND BA.CDFILIAL    = BP.CDFILIBAIPAG
           AND BA.NRBAIXAPAG  = BP.NRBAIXAPAG) LOOP

           SELECT COUNT(*) INTO V_CTBOLF
           FROM BOLETPAGAR
           WHERE CDFILIBAIPAG = C_BAIP.CDFILIAL
             AND NRBAIXAPAG   = C_BAIP.NRBAIXAPAG
             AND DTVENBOLPAG  > P_DTLIMITE;

           IF (V_CTBOLF > 0) OR
              (C_BAIP.DTBAIXAPAG > P_DTLIMITE) THEN
              V_CTERRO := V_CTERRO + 1;
           END IF;
      END LOOP;

      IF (V_CTBOLFORA > 0) OR (V_CTERRO > 0) THEN
         P_EXCLUSAOOK := 'N';
      END IF;
   END IF;

   /*************************************************************************/
   /*  VERIFICA SE AS CONTAS A RECEBER, BOLETOS E BAIXAS PODEM SER EXCLUDOS  */

   SELECT COUNT(CDFILIAL) INTO V_CTCNTREC
   FROM  CONTARECEBER
   WHERE CDFILIAL   = P_CDFILIAL
     AND NRLANCTONF = P_NRLANCTONF;

   IF V_CTCNTREC > 0 THEN
      /* VERIFICA SE EXISTE BOLETO ACIMA DA DATA LIMITE */
      SELECT COUNT(*) INTO V_CTBOLFORA
      FROM BOLETRECEBER BR, CONTARECEBER CR
      WHERE CR.CDFILIAL    = P_CDFILIAL
        AND CR.NRLANCTONF  = P_NRLANCTONF
        AND BR.CDFILIAL    = CR.CDFILIBOLREC
        AND BR.NRLANBOLREC = CR.NRLANBOLREC
        AND BR.DTVENBOLREC > P_DTLIMITE;

      /* VERIFICA SE EXISTE BAIXA ACIMA DA DATA LIMITE OU OUTROS BOLETOS ACIMA DA DATA LIGADOS A BAIXA*/
      V_CTERRO := 0;
      FOR C_BAIR IN
        (SELECT DISTINCT BA.CDFILIAL, BA.NRBAIXAREC, BA.DTBAIXAREC
         FROM BAIXARECEBIDA BA, BOLETRECEBER BR, CONTARECEBER CR
         WHERE CR.CDFILIAL    = P_CDFILIAL
           AND CR.NRLANCTONF  = P_NRLANCTONF
           AND BR.CDFILIAL    = CR.CDFILIBOLREC
           AND BR.NRLANBOLREC = CR.NRLANBOLREC
           AND BA.CDFILIAL    = BR.CDFILIBAIREC
           AND BA.NRBAIXAREC  = BR.NRBAIXAREC) LOOP

           SELECT COUNT(*) INTO V_CTBOLF
           FROM BOLETRECEBER
           WHERE CDFILIBAIREC = C_BAIR.CDFILIAL
             AND NRBAIXAREC   = C_BAIR.NRBAIXAREC
             AND DTVENBOLREC  > P_DTLIMITE;

           IF (V_CTBOLF > 0) OR
              (C_BAIR.DTBAIXAREC > P_DTLIMITE) THEN
              V_CTERRO := V_CTERRO + 1;
           END IF;
      END LOOP;

      IF (V_CTBOLFORA > 0) OR (V_CTERRO > 0) THEN
         P_EXCLUSAOOK := 'N';
      END IF;
   END IF;

   /*************************************************************************/
   /*  EXCLUI AS CONTAS A PAGAR E RECEBER DA NOTA FISCAL */

   IF P_EXCLUSAOOK = 'S' THEN

      IF V_CTCNTPAG > 0 THEN
          EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_CTPAGAR DISABLE';
          EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_BOLETPAG DISABLE';
          EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_BXPAGAR DISABLE';

          FOR C_CNTPAG IN
            (SELECT
                ROWID,        CDFILIAL,    NRLANCTONF,  NRSEQVENPAG,
                NRPARCELAPAG, CDFILIBPAG,  NRLANBOLPAG
             FROM CONTAPAGAR
             WHERE CDFILIAL    = P_CDFILIAL
               AND NRLANCTONF  = P_NRLANCTONF) LOOP

             DELETE FROM AJCTPAGAR
             WHERE (CDFILIAL     = C_CNTPAG.CDFILIAL)
               AND (NRLANCTONF   = C_CNTPAG.NRLANCTONF)
               AND (NRSEQVENPAG  = C_CNTPAG.NRSEQVENPAG)
               AND (NRPARCELAPAG = C_CNTPAG.NRPARCELAPAG);

             DELETE FROM ADIANTAPAGAR
             WHERE (CDFILIAL     = C_CNTPAG.CDFILIAL)
               AND (NRLANCTONF   = C_CNTPAG.NRLANCTONF)
               AND (NRSEQVENPAG  = C_CNTPAG.NRSEQVENPAG)
               AND (NRPARCELAPAG = C_CNTPAG.NRPARCELAPAG);

             DELETE FROM CONTAPAGAR
             WHERE ROWID = C_CNTPAG.ROWID;

             FOR C_BOLPAG IN
               (SELECT BP.ROWID,
                     BP.CDFILIAL, BP.NRLANBOLPAG, BP.CDFILIBAIPAG, BP.NRBAIXAPAG
                FROM BOLETPAGAR BP, CONTAPAGAR CP
                WHERE CP.CDFILIAL     = P_CDFILIAL
                  AND CP.NRLANCTONF   = P_NRLANCTONF
                  AND BP.CDFILIAL     = CP.CDFILIBPAG
                  AND BP.NRLANBOLPAG  = CP.NRLANBOLPAG) LOOP

                SELECT COUNT(*) INTO V_CTBOL
                FROM CONTAPAGAR
                WHERE CDFILIBPAG  = C_BOLPAG.CDFILIAL
                  AND NRLANBOLPAG = C_BOLPAG.NRLANBOLPAG;

                IF V_CTBOL = 0 THEN
                   DELETE FROM AJBOLPAG
                   WHERE (CDFILIAL    = C_BOLPAG.CDFILIAL)
                     AND (NRLANBOLPAG = C_BOLPAG.NRLANBOLPAG);

                   DELETE FROM BOLETPAGAR
                   WHERE ROWID = C_BOLPAG.ROWID;
                END IF;

                SELECT COUNT(*) INTO V_CTBAIXA
                FROM BOLETPAGAR
                WHERE CDFILIBAIPAG = C_BOLPAG.CDFILIBAIPAG
                  AND NRBAIXAPAG   = C_BOLPAG.NRBAIXAPAG;

                IF V_CTBAIXA = 0 THEN
                   DELETE FROM TPPAGBAIXA
                   WHERE CDFILIAL   = C_BOLPAG.CDFILIBAIPAG
                     AND NRBAIXAPAG = C_BOLPAG.NRBAIXAPAG;

                   DELETE FROM BAIXAPAGA
                   WHERE CDFILIAL   = C_BOLPAG.CDFILIBAIPAG
                     AND NRBAIXAPAG = C_BOLPAG.NRBAIXAPAG;
                END IF;
             END LOOP;
          END LOOP;

          EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_CTPAGAR ENABLE';
          EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_BOLETPAG ENABLE';
          EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_BXPAGAR ENABLE';
      END IF;

      IF V_CTCNTREC > 0 THEN
         EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_CTRECEBER DISABLE';
         EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_BOLETREC DISABLE';
         EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_BXRECEBER DISABLE';

         FOR C_CNTREC IN
          (SELECT ROWID,
              CDFILIAL, NRLANCTONF, NRSEQVENREC, NRPARCELAREC
           FROM CONTARECEBER
           WHERE CDFILIAL    = P_CDFILIAL
             AND NRLANCTONF  = P_NRLANCTONF) LOOP

            DELETE FROM AJCTRECEBER
            WHERE (CDFILIAL     = C_CNTREC.CDFILIAL)
              AND (NRLANCTONF   = C_CNTREC.NRLANCTONF)
              AND (NRSEQVENREC  = C_CNTREC.NRSEQVENREC)
              AND (NRPARCELAREC = C_CNTREC.NRPARCELAREC);

            DELETE FROM PARCELAVENDA
            WHERE (CDFILIAL     = C_CNTREC.CDFILIAL)
              AND (NRLANCTONF   = C_CNTREC.NRLANCTONF)
              AND (NRSEQVENREC  = C_CNTREC.NRSEQVENREC)
              AND (NRPARCELAREC = C_CNTREC.NRPARCELAREC);

            DELETE FROM CONTARECEBER
            WHERE ROWID = C_CNTREC.ROWID;

            FOR C_BOLREC IN
               (SELECT BR.ROWID,
                   BR.CDFILIAL, BR.NRLANBOLREC, BR.CDFILIBAIREC, BR.NRBAIXAREC
                FROM BOLETRECEBER BR, CONTARECEBER CR
                WHERE CR.CDFILIAL    = P_CDFILIAL
                  AND CR.NRLANCTONF  = P_NRLANCTONF
                  AND BR.CDFILIAL    = CR.CDFILIBOLREC
                  AND BR.NRLANBOLREC = CR.NRLANBOLREC
                  AND BR.DTVENBOLREC <= P_DTLIMITE) LOOP

                SELECT COUNT(*) INTO V_CTBOL
                FROM CONTARECEBER
                WHERE CDFILIBOLREC = C_BOLREC.CDFILIAL
                  AND NRLANBOLREC  = C_BOLREC.NRLANBOLREC;

                IF V_CTBOL = 0 THEN
                   DELETE FROM AJBOLREC
                   WHERE (CDFILIAL    = C_BOLREC.CDFILIAL)
                     AND (NRLANBOLREC = C_BOLREC.NRLANBOLREC);

                   DELETE FROM BOLETRECEBER
                   WHERE ROWID = C_BOLREC.ROWID;
                END IF;

                SELECT COUNT(*) INTO V_CTBAIXA
                FROM BOLETRECEBER
                WHERE CDFILIBAIREC = C_BOLREC.CDFILIBAIREC
                  AND NRBAIXAREC   = C_BOLREC.NRBAIXAREC;

                IF V_CTBAIXA = 0 THEN
                   DELETE FROM TPRECBAIXA
                   WHERE CDFILIAL   = C_BOLREC.CDFILIBAIREC
                     AND NRBAIXAREC = C_BOLREC.NRBAIXAREC;

                   DELETE FROM BAIXARECEBIDA
                   WHERE CDFILIAL   = C_BOLREC.CDFILIBAIREC
                     AND NRBAIXAREC = C_BOLREC.NRBAIXAREC;
                END IF;
            END LOOP;
         END LOOP;

         EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_CTRECEBER ENABLE';
         EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_BOLETREC ENABLE';
         EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIN_BXRECEBER ENABLE';
      END IF;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('LIMPA_CONTA_FINANC','4.09.066'); END;
/

